@@ -282,12 +282,11 @@ def five_column_100_row_dataset():
 
 @pytest.fixture(scope="session")
 def batch_rows():
-    return 10000
+    return 200000
 
 
 @pytest.fixture(scope="session")
-def generate_batch(batch_rows):
-    start = time.time()
+def batch(batch_rows):
     size = batch_rows
     df = pd.DataFrame(columns=['First', 'Last', 'Gender', 'Birthdate'])
     df['First'] = random_names('first_names', size)
@@ -295,50 +294,56 @@ def generate_batch(batch_rows):
     df['Gender'] = random_genders(size)
     df['BirthDate'] = random_dates(start=pd.to_datetime('1940-01-01'), end=pd.to_datetime('2022-01-01'), size=size)
     df['StartDate'] = random_dates(start=pd.to_datetime('1940-01-01'), end=pd.to_datetime('2022-01-01'), size=size)
-    end = time.time()
-    return [to_dc_format(df), end - start]
+    return to_dc_format(df)
 
 
-@pytest.fixture(scope="session", params=[0.25, 0.5, 1.0, 10.0, 100.0, 1000.0])
+@pytest.fixture(scope="session", params=[0.1, 0.25, 0.5, 1.0, 10.0, 100.0, 1000.0])
 def num_gigs(request):
     return request.param
 
 
 @pytest.fixture(scope="session")
-def load_data(connector, generate_batch, good_object_id, mapping_object, _replace, num_gigs, batch_size, batch_rows):
-    start = time.time()
+def load_data(connector, batch, good_object_id, mapping_object, _replace, num_gigs, batch_size, batch_rows):
+    print(f"\nNow loading {num_gigs} GB!")
     size = num_gigs
     batch_number = 1
     rows_loaded = 0
     generate_data_time = 0
+    elapsed_time = 0
+    total_batches = math.ceil((size * GB) / float(sys.getsizeof(batch)))
 
-    batch = generate_batch
-    total_batches = math.ceil((size * GB) / float(sys.getsizeof(batch[0])))
-    generate_data_time += batch[1]
-    connector.load_data(batch[0], good_object_id, mapping_object, _replace, batch_number, total_batches)
+    start = time.time()
+    connector.load_data(batch, good_object_id, mapping_object, _replace, batch_number, total_batches)
+    end = time.time()
+    elapsed_time += (end - start)
 
     while batch_number <= total_batches:
-        rows_loaded += len(batch[0])
-        print(f"Batch {batch_number}/{total_batches}: Loaded {rows_loaded} rows out of {total_batches * batch_rows}")
+        rows_loaded += len(batch)
+        print(f"Batch {batch_number}/{total_batches}: Loaded {rows_loaded} rows out of {total_batches * batch_rows} "
+              f"in {elapsed_time} seconds.")
         batch_number += 1
-        batch = generate_batch
-        generate_data_time += batch[1]
-        connector.load_data(batch[0], good_object_id, mapping_object, _replace, batch_number, total_batches)
 
-    end = time.time()
+        start = time.time()
+        connector.load_data(batch, good_object_id, mapping_object, _replace, batch_number, total_batches)
+        end = time.time()
+        elapsed_time += (end - start)
+
     print(f"Loaded {rows_loaded} rows out of {total_batches * batch_rows}."
           f"\nTotal size uploaded: {size * GB} bytes, which is {size} GB.")
+    with open("load_test_results.txt", "a") as f:
+        f.write(f"LoadTest for {size} GB")
+        f.write(f"Loaded {rows_loaded} rows out of {total_batches * batch_rows}."
+                f"\nTotal size uploaded: {size * GB} bytes, which is {size} GB.")
 
-    elapsed_time = end - start - generate_data_time
-    hours = elapsed_time / (60. * 60.)
-    minutes = (elapsed_time % (60. * 60.)) / 60.
-    seconds = (elapsed_time % (60. * 60.)) % 60.
-    formatted_time = f"{hours} Hours {minutes} Minutes and {seconds} seconds"
+        hours = math.floor(elapsed_time / (60. * 60.))
+        minutes = math.floor((elapsed_time % (60. * 60.)) / 60.)
+        seconds = (elapsed_time % (60. * 60.)) % 60.
+        formatted_time = f"{hours} Hours {minutes} Minutes and {seconds} Seconds"
 
-    print(f"Time elapsed to load {num_gigs} GB: {formatted_time}.")
-    print(f"\t({end - start} total seconds - {generate_data_time} seconds to generate data)")
-    assert elapsed_time < (10. * 60.)
-    return True
+        print(f"Time elapsed to load {num_gigs} GB: {formatted_time}.")
+        f.write(f"Time elapsed to load {num_gigs} GB: {formatted_time}.")
+        assert elapsed_time < (10. * 60.)
+        return True
 
 
 @pytest.fixture(scope="session")
